@@ -169,6 +169,8 @@ NO_OF_TRAINING_JOBS = "noOfTrainingJob"
 # supported entity types
 NER_TYPES = [PRE_TRAINED, LOOKUP, SYNONYM, REGEX]
 USER_DEFINED_ENTITY_TYPES = [LOOKUP, SYNONYM, REGEX]
+TRAIN = "train"
+TEST = "test"
 
 
 # Follow up Commands
