@@ -470,7 +470,7 @@ def print_models_table(models: Dict[Text, Any], verbose: bool):
         table.add_column("Entity Partial F1")
         table.add_column("Training Time (sec)")
         table.add_column("Last Updated")
-        table.add_column("Training Message")
+        table.add_column("Message")
 
     console.print(
         f"> {INFO} {NUMBERS_IN_SQUARE} Total Models Count: {models[DATA][COUNT]}"
@@ -493,7 +493,7 @@ def print_models_table(models: Dict[Text, Any], verbose: bool):
                 if data[TRAINING_STATUS] == COMPLETED
                 else "0.0",
                 str(data[LAST_STATUS_UPDATED]),
-                data[MESSAGE],
+                data.get(MESSAGE, ""),
             ]
         table.add_row(*args)
     console.print(table)
@@ -597,8 +597,8 @@ async def upload_dataset(
             data=json.dumps(batch, ensure_ascii=False),
             headers=HEADERS,
         ) as response:
-            json_response = await response.json(encoding="utf-8")
             if is_success_status(response.status):
+                json_response = await response.json(encoding="utf-8")
                 if current_example_number % 3 == 0:
                     if animation_tracker == 1:
                         progress_bar.update(task_id=task, description="🏃")
@@ -612,6 +612,12 @@ async def upload_dataset(
                 responses.append(json_response)
                 progress_bar.update(task_id=task, completed=current_example_number)
             else:
+                if "text/html" in response.content_type:
+                    message = response.text()
+                else:
+                    json_response = await response.json(encoding="utf-8")
+                    message = json_response[MESSAGE]
+                json_response = await response.json(encoding="utf-8")
                 console.print(
                     f"> {ERROR} {CROSS} Failed to upload example with text "
                     f"{DARK_ORANGE_START}{example['text']}{DARK_ORANGE_END}"
@@ -621,7 +627,7 @@ async def upload_dataset(
                     f"> Failed on example: \n{json.dumps(example, indent=4, ensure_ascii=False)}"
                 )
                 console.print(
-                    f'''> Reason for failure {SAD_SMILEY}: " {RED_START}{json_response[MESSAGE]}{RED_END} "'''
+                    f'''> Reason for failure {SAD_SMILEY}: " {RED_START}{message}{RED_END} "'''
                 )
                 error_examples.append(example)
                 if ignore_errors:
@@ -783,7 +789,8 @@ async def deploy(model_id: Text, n_replicas: int) -> Dict[Text, Any]:
         if is_success_status(response.status):
             console.print(f"> {INFO} {GREEN_TICK} Model added to deployment queue.")
             console.print(
-                f"{FAST_FORWARD} Check for replicas in model status to know that the model got deployed: "
+                f"{FAST_FORWARD} Check for replicas in model status to know that the model got deployed "
+                f"(use the --verbose flag): "
                 f"{DARK_ORANGE_START}{LIST_MODELS_COMMAND}{DARK_ORANGE_END}"
             )
             console.print(
